[Bug gcov-profile/90364] 521.wrf_r is 9.5 % slower with PGO on Zen CPUs at -Ofast and native march/mtune

marxin at gcc dot gnu.org gcc-bugzilla@gcc.gnu.org
Tue May 7 12:29:00 GMT 2019


https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90364

--- Comment #3 from Martin Liška <marxin at gcc dot gnu.org> ---
So the problem is that without a profile tree-vectorizer does a vectorization
in 1162 functions, while with PGO only 49 functions are vectorized.
Can you please Richi take a look? I can provide vectorizer dump files.


More information about the Gcc-bugs mailing list